from Products.Archetypes.public import *
from Products.Archetypes.Marshall import RFC822Marshaller
from Products.CMFCore import CMFCorePermissions
from config import PROJECTNAME
from form_inputs import HTMLFormInputParser

"""
PayPal items for building a shopping cart store (or can be used single item).
http://www.zope.org/Members/bowerymarc

"""

def modify_fti(fti):
    # hide unnecessary tabs (usability enhancement)
    for a in fti['actions']:
        if a['id'] in ('references',):
            a['visible'] = 0
    return fti


schema = BaseSchema +  Schema((
    TextField('addtocart',
                required=1,
                widget=TextAreaWidget(description='add to cart button code from PayPal', rows=17, cols=80,),
                default_output_type='text/html',
                allowable_content_types=('text/html',),
             ),
    TextField('short_description',
              searchable=1,
              widget=RichWidget(label='Description',
                                    description='description of the item',
                                    ),
              required=1,
              default_output_type='text/html',
              allowable_content_types=('text/plain',
                       'text/structured',
                       'text/html'),
              accessor='getShortDescription',
              edit_accessor='getShortDescription',
              mutator='setShortDescription',
              ),
    ImageField('image',
                default_output_type='image/jpeg',
                allowable_content_types=('image/*',),
                widget=ImageWidget(description='upload a picture or image of the item', macro_view='flex_image'),
              ),
    BooleanField('instock',
                index='FieldIndex:schema',
                description='in stock?',
                widget=BooleanWidget(description='is item in stock?'),
                ),
    ),
    marshall=RFC822Marshaller(),
    )

class PayPalItem(BaseContent):
    """
Simple way to let users create a paypal store item.
    """

    schema = schema

    actions = ({
        'id': 'view',
        'name': 'View',
        'action': 'string:${object_url}/paypalitem_view',
        'permissions': (CMFCorePermissions.View,)
        },)
        
    content_icon = "cart1_icon.gif"
    
    parser = HTMLFormInputParser()
    
    def formInputs(self, html=''):
        """parse html and return dictionary of name:value pairs of all input fields
        """
        self.parser.reset()
        self.parser.clearDict()
        self.parser.feed(html)
#        self.parser.close()
        return self.parser.getDict()
     


    # enable field sharing between 'short_description' and 'description'
    def Description(self, **kw):
        """ get the 'description' and put it in the 'short_description'
        """
        return self.getShortDescription()

    def setDescription(self, val, **kw):
        """ synchronize 'short_description' and 'description'
        """
        self.setShortDescription(val)

#     def getShortDescription(self, **kw):
#         """ get the 'description' and put it in the 'short_description'
#         """
#         return self.Description()
# 
#     def setShortDescription(self, val, **kw):
#         """ synchronize 'short_description' and 'description'
#         """
#         self.setDescription(val)
        
registerType(PayPalItem, PROJECTNAME)
